==> react-notie-1.1.0.tgz: package/es6/NotieProvider.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component, PropTypes } from 'react';

import notieContextShape from './context-shape';
import Notie from './Notie';

var NotieProvider = function (_Component) {
    _inherits(NotieProvider, _Component);

    function NotieProvider() {
        var _ref;

        var _temp, _this, _ret;

        _classCallCheck(this, NotieProvider);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = NotieProvider.__proto__ || Object.getPrototypeOf(NotieProvider)).call.apply(_ref, [this].concat(args))), _this), _this.notieRef = function (c) {
            _this.notie = c;
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(NotieProvider, [{
        key: 'getChildContext',


        /* istanbul ignore next */
        value: function getChildContext() {
            var _this2 = this;

            return {
                notie: {
                    alert: function alert() {
                        var _notie;

                        return (_notie = _this2.notie).alert.apply(_notie, arguments);
                    },
                    confirm: function confirm() {
                        var _notie2;

                        return (_notie2 = _this2.notie).confirm.apply(_notie2, arguments);
                    },
                    success: function success() {
                        var _notie3;

                        return (_notie3 = _this2.notie).success.apply(_notie3, arguments);
                    },
                    warn: function warn() {
                        var _notie4;

                        return (_notie4 = _this2.notie).warn.apply(_notie4, arguments);
                    },
                    error: function error() {
                        var _notie5;

                        return (_notie5 = _this2.notie).error.apply(_notie5, arguments);
                    },
                    info: function info() {
                        var _notie6;

                        return (_notie6 = _this2.notie).info.apply(_notie6, arguments);
                    }
                }
            };
        }
    }, {
        key: 'render',
        value: function render() {
            var _props = this.props,
                children = _props.children,
                rest = _objectWithoutProperties(_props, ['children']);

            return React.createElement(
                'div',
                null,
                children,
                React.createElement(Notie, _extends({ ref: this.notieRef }, rest))
            );
        }
    }]);

    return NotieProvider;
}(Component);

NotieProvider.childContextTypes = {
    notie: notieContextShape
};
NotieProvider.propTypes = {
    children: PropTypes.node.isRequired
};


export default NotieProvider;

==> react-notie-1.2.2.tgz: package/es6/NotieProvider.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

import notieContextShape from './context-shape';
import Notie from './Notie';

var NotieProvider = function (_Component) {
    _inherits(NotieProvider, _Component);

    function NotieProvider() {
        var _ref;

        var _temp, _this, _ret;

        _classCallCheck(this, NotieProvider);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = NotieProvider.__proto__ || Object.getPrototypeOf(NotieProvider)).call.apply(_ref, [this].concat(args))), _this), _this.notieRef = function (c) {
            _this.notie = c;
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(NotieProvider, [{
        key: 'getChildContext',


        /* istanbul ignore next */
        value: function getChildContext() {
            var _this2 = this;

            return {
                notie: {
                    alert: function alert() {
                        var _notie;

                        return (_notie = _this2.notie).alert.apply(_notie, arguments);
                    },
                    confirm: function confirm() {
                        var _notie2;

                        return (_notie2 = _this2.notie).confirm.apply(_notie2, arguments);
                    },
                    success: function success() {
                        var _notie3;

                        return (_notie3 = _this2.notie).success.apply(_notie3, arguments);
                    },
                    warn: function warn() {
                        var _notie4;

                        return (_notie4 = _this2.notie).warn.apply(_notie4, arguments);
                    },
                    error: function error() {
                        var _notie5;

                        return (_notie5 = _this2.notie).error.apply(_notie5, arguments);
                    },
                    info: function info() {
                        var _notie6;

                        return (_notie6 = _this2.notie).info.apply(_notie6, arguments);
                    }
                }
            };
        }
    }, {
        key: 'render',
        value: function render() {
            var _props = this.props,
                children = _props.children,
                rest = _objectWithoutProperties(_props, ['children']);

            return React.createElement(
                'div',
                null,
                children,
                React.createElement(Notie, _extends({ ref: this.notieRef }, rest))
            );
        }
    }]);

    return NotieProvider;
}(Component);

NotieProvider.childContextTypes = {
    notie: notieContextShape
};
NotieProvider.propTypes = {
    children: PropTypes.node.isRequired };


export default NotieProvider;
